@@ -2,6 +2,7 @@
 #ifdef LINUX2
 #define HAVE_DAEMON
 #define HAVE_GETRUSAGE
+#define SOCKLEN_T	socklen_t
 #define PATH_TMP	"/tmp"
 #define PATH_VAR_TMP	"/var/tmp"
 #define PATH_PASSWD	"/etc/passwd"
@@ -13,6 +14,7 @@
 
 #ifdef HPUX10
 #define HAVE_GETRUSAGE
+#define SOCKLEN_T	int
 #define PATH_TMP	"/tmp"
 #define PATH_VAR_TMP	"/var/tmp"
 #define PATH_PASSWD	"/etc/passwd"
@@ -25,6 +27,7 @@
 #ifdef TRU64
 #define HAVE_GETRUSAGE
 #define SIZEOF_IS_LONG_INT
+#define SOCKLEN_T	size_t
 #define PATH_TMP	"/tmp"
 #define PATH_VAR_TMP	"/var/tmp"
 #define PATH_PASSWD	"/etc/passwd"
@@ -37,6 +40,13 @@
 #ifdef SUNOS
 #define HAVE_GETRUSAGE
 #define PID_T_IS_LONG_INT
+#if 0
+/*
+ * Do not use socklen_t, as I found it in the Solaris 7 manual page but
+ * not for Solaris 2.4. Play it safe and use the "int" default below.
+ */
+#define SOCKLEN_T	socklen_t
+#endif
 #define PATH_TMP        "/tmp"
 #define PATH_VAR_TMP    "/var/tmp"
 #define PATH_PASSWD     "/etc/passwd"
@@ -46,6 +56,8 @@
 #endif
 
 #ifdef NEXTSTEP3
+#define HAVE_GETRUSAGE
+#define SIZEOF_IS_LONG_INT
 /* not supported */
 #define SA_RESTART 0
 #define O_RSYNC 0
@@ -61,8 +73,6 @@
 #ifndef FD_CLOEXEC
 #define FD_CLOEXEC	1
 #endif
-#define SIZEOF_IS_LONG_INT
-#define HAVE_GETRUSAGE
 #define PATH_TMP        "/private/tmp"
 #define PATH_PASSWD     "/etc/passwd"
 #define PATH_WTMP       "/private/adm/wtmp"
@@ -70,7 +80,7 @@
 #define PATH_SYSLOG     "/private/adm/messages"
 #endif
 
-#ifdef IRIX62
+#ifdef IRIX6
 #define HAVE_GETRUSAGE
 #define PID_T_IS_LONG_INT
 #define PATH_TMP        "/tmp"
@@ -82,11 +92,12 @@
 #endif
 
 #ifdef AIX43
+#define HAVE_GETRUSAGE
 #if defined(__64BIT_KERNEL) && defined(_KERNEL)
 #define PID_T_IS_LONG_INT
 #endif /* __64BIT_KERNEL && _KERNEL */
 #define SIZEOF_IS_LONG_INT
-#define HAVE_GETRUSAGE
+#define SOCKLEN_T	size_t
 #define PATH_TMP	"/tmp"
 #define PATH_VAR_TMP	"/var/tmp"
 #define PATH_PASSWD	"/etc/passwd"
@@ -99,6 +110,7 @@
 #ifdef UNIXWARE7
 #define HAVE_GETRUSAGE
 #define PID_T_IS_LONG_INT
+#define SOCKLEN_T	size_t
 #define O_RSYNC		0
 #define PATH_TMP        "/tmp"
 #define PATH_VAR_TMP    "/var/tmp"
@@ -118,7 +130,7 @@
 
 #ifdef SCO
 #define HAVE_GETRUSAGE
-#define PID_T_IS_LONG_INT
+#define SOCKLEN_T	int
 #define O_RSYNC		0
 #define PATH_TMP        "/tmp"
 #define PATH_VAR_TMP    "/var/tmp"
@@ -160,6 +172,13 @@
 #define SHUT_RDWR	2
 #endif
 
+/*
+ * If SOCKLEN_T is not defined, use a default.
+ */
+#ifndef SOCKLEN_T
+#define SOCKLEN_T	int
+#endif
+
 /*
  * The pool size of the OpenSSL PRNG
  */
