@@ -17,8 +17,8 @@ void non_blocking(int fd, int on)
 {
   int flags;
 
-  if ((flags = fcntl(fd, F_GETFL, 0)) < 0)
+  if ((flags = fcntl(fd, F_GETFL, 0)) == -1)
     abort();
-  if (fcntl(fd, F_SETFD, on ? flags | PATTERN : flags & ~PATTERN) < 0)
+  if (fcntl(fd, F_SETFL, on ? flags | PATTERN : flags & ~PATTERN) == -1)
     abort();
 }
