@@ -112,7 +112,7 @@ static void write_seedfile(void)
   bytes = rand_bytes(buffer, PRNGD_STATE_SIZE);
   if (bytes == 0)
   {
-    fprintf(stderr, "Could not retrieve rand_bytes\n");
+    fprintf(stderr, "Info: Random pool not (yet) seeded\n");
   }
   else
   {
@@ -471,7 +471,7 @@ int main(int argc, char *argv[])
       exit(EXIT_FAILURE);
     }
 
-    if (pwent = getpwuid(getuid()))
+    if ((pwent = getpwuid(getuid())) != NULL)
       username = pwent->pw_name;
     /*
      * The setup is finished, and we are daemonized, so we must now switch
