@@ -38,6 +38,8 @@ typedef struct {
 extern int randsavefd;
 extern int debug;
 extern int devnull;
+extern int limit_openfd;
+extern int count_openfd;
 
 void parse_configfile(const char *cmdpath, entropy_source_t **entropy_source);
 
@@ -83,3 +85,5 @@ void non_blocking(int fd, int on);
 
 ssize_t socket_read(int fd, void *buf, size_t num);
 ssize_t socket_write(int fd, void *buf, size_t num);
+
+int obtain_limit(void);
