@@ -80,7 +80,7 @@ void main_loop(int *service_socket, int numsock, struct sockaddr_un sockun,
 {
   int i;
   int accept_fd;
-  int sockunlen;
+  SOCKLEN_T sockunlen;
   int num, numbytes, error;
   int pipedes[2];
   time_t last_seed_stat = 0, last_seed_ext = 0;
